@@ -20,6 +20,6 @@ class FacebookCommentCache(models.Model):
 		try:
 			comments = json.loads(obj.content)
 			data = comments[href]['data']
-		except ValueError, AttributeError, KeyError:
+		except (ValueError, AttributeError, KeyError):
 			return []
 		return data
